package org.jeecg.modules.app.service.impl;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.bean.WxMaJscode2SessionResult;
import cn.binarywang.wx.miniapp.util.WxMaConfigHolder;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.extern.log4j.Log4j2;
import me.chanjar.weixin.common.error.WxErrorException;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.system.util.JwtUtil;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.RedisUtil;
import org.jeecg.modules.app.service.IUserService;
import org.jeecg.modules.app.vo.LoginUserVO;
import org.jeecg.modules.app.vo.MsgInfoVO;
import org.jeecg.modules.app.vo.MsgVO;
import org.jeecg.modules.system.entity.SysAnnouncement;
import org.jeecg.modules.system.entity.SysAnnouncementSend;
import org.jeecg.modules.system.entity.SysUser;
import org.jeecg.modules.system.mapper.SysAnnouncementMapper;
import org.jeecg.modules.system.mapper.SysAnnouncementSendMapper;
import org.jeecg.modules.system.mapper.SysUserMapper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

import static org.jeecg.common.constant.CommonConstant.PREFIX_USER_TOKEN;
import static org.jeecg.common.constant.CommonConstant.SC_INTERNAL_SERVER_ERROR_500;

@Service
@Log4j2
public class UserServiceImpl implements IUserService {
    @Resource
    private WxMaService wxMaService;
    @Resource
    private SysUserMapper sysUserMapper;
    @Resource
    private SysAnnouncementSendMapper sysAnnouncementSendMapper;
    @Resource
    private SysAnnouncementMapper sysAnnouncementMapper;
    @Autowired
    private RedisUtil redisUtil;

    @Override
    public LoginUserVO wechatLogin(String code) {
        try {
            WxMaJscode2SessionResult session = wxMaService.getUserService().getSessionInfo(code);
            String openid = session.getOpenid();
            // 通过openId获取在系统中是否是已经绑定过的用户
            SysUser user = sysUserMapper.selectOne(Wrappers.<SysUser>lambdaQuery()
                    .eq(SysUser::getOpenid, openid)
                    .eq(SysUser::getDelFlag, 0));
            if (null == user) {
                // 用户不存在则创建
                    user = new SysUser()
                            .setOpenid(openid)
                            .setRealname("微信用户")
                            .setUsername("微信用户")
                            .setOrgCode("A03");
                    boolean result = sysUserMapper.insert(user) > 0;
                    if (!result) {
                        throw new JeecgBootException("登录失败", SC_INTERNAL_SERVER_ERROR_500);
                }
            }
            return generateLoginUserVO(user);
        } catch (WxErrorException e) {
            log.error("微信登录失败: {}", e.getMessage());
            throw new JeecgBootException("小程序登录失败:" + e, SC_INTERNAL_SERVER_ERROR_500);
        } finally {
            WxMaConfigHolder.remove(); // 清理ThreadLocal
        }
    }

    @Override
    public List<MsgVO> getMsg() {
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        List<MsgVO> msgVOList = new ArrayList<>();
        sysAnnouncementSendMapper.selectList(Wrappers.<SysAnnouncementSend>lambdaQuery()
                .eq(SysAnnouncementSend::getUserId, user.getId())).forEach(sysAnnouncementSend -> {
            SysAnnouncement sysAnnouncement = sysAnnouncementMapper.selectById(sysAnnouncementSend.getAnntId());
            MsgVO msgVO = new MsgVO()
                    .setReadFlag(sysAnnouncementSend.getReadFlag())
                    .setTitile(sysAnnouncement.getTitile())
                    .setSendTime(sysAnnouncement.getSendTime())
                    .setImgUrl(sysAnnouncement.getImgUrl()).setSender(sysAnnouncement.getSender());
            msgVOList.add(msgVO);
        });
        return msgVOList;
    }

    @Override
    public MsgInfoVO getMsgInfo(String id) {
        SysAnnouncement sysAnnouncement = sysAnnouncementMapper.selectById(id);
        MsgInfoVO msgInfoVO = new MsgInfoVO();
        BeanUtils.copyProperties(sysAnnouncement, msgInfoVO);
        return msgInfoVO;
    }

    private LoginUserVO generateLoginUserVO(SysUser user) {
        String orgCode = user.getOrgCode().substring(0, 3);
        String userAccount = "";
        String userPassword = "";
        if(orgCode.equals("A03") || user.getOpenid() != null){
            userAccount = user.getUsername();
            userPassword = user.getOpenid();
        }else if (orgCode.equals("A04")){
            userAccount = user.getUsername();
            userPassword = user.getPassword();
        }
        // 1.生成token
        String token = JwtUtil.sign(userAccount, userPassword);
        // 设置token缓存有效时间
        redisUtil.set(PREFIX_USER_TOKEN + token, token);
        redisUtil.expire(PREFIX_USER_TOKEN + token, JwtUtil.EXPIRE_TIME * 2 / 1000);
        return new LoginUserVO().setToken(token)
                .setId(user.getId())
                .setUserName(user.getUsername())
                .setUserAvatar(user.getAvatar());
    }
}